@@ -4,7 +4,7 @@ use 5.016;
 use warnings;
 
 package Proch::N50;
-$Proch::N50::VERSION = '0.022';
+$Proch::N50::VERSION = '0.023';
 
 use File::Basename;
 use Exporter qw(import);
@@ -159,7 +159,7 @@ Proch::N50 - Calculate N50 from a FASTA or FASTQ file without dependencies
 
 =head1 VERSION
 
-version 0.022
+version 0.023
 
 =head1 SYNOPSIS
 
@@ -167,11 +167,11 @@ version 0.022
   my $filepath = '/path/to/assembly.fasta';
 
   # Get N50 only: getN50(file) will return an integer
-  say "N50 only:\t" ,getN50($filepath);
+  print "N50 only:\t", getN50($filepath), "\n";
 
   # Full stats
   my $seq_stats = getStats($filepath);
-  say Data::Dumper->Dump( [ $seq_stats ], [ qw(*FASTA_stats) ] );
+  print Data::Dumper->Dump( [ $seq_stats ], [ qw(*FASTA_stats) ] );
   # Will print:
   # %FASTA_stats = (
   #               'N50' => 65,
@@ -184,7 +184,7 @@ version 0.022
 
   # Get also a JSON object
   my $seq_stats_with_JSON = getStats($filepath, 'JSON');
-  say $seq_stats_with_JSON->{json};
+  print $seq_stats_with_JSON->{json}, "\n";
   # Will print:
   # {
   #    "seqs" : 6,
